@@ -1,5 +1,6 @@
 from wack.builders import PackageBuilt
 from wack.builders import PipInstallable
-from wack.core import command, echo
+from wack.core import command
+from wack.core import echo
 
 __all__ = ["PackageBuilt", "PipInstallable", "command", "echo"]
